@@ -4,7 +4,6 @@ test_that(
   desc = "contingency_table works - data without NAs",
   code = {
 
-
     # `statsExpressions` output
     set.seed(123)
     using_function1 <-
@@ -231,7 +230,6 @@ test_that(
   desc = "paired contingency_table works - with NAs",
   code = {
 
-
     # create data structure
     paired_data <-
       structure(
@@ -315,137 +313,6 @@ test_that(
   }
 )
 
-# paired data 4-by-4  ---------------------------------------------
-
-test_that(
-  desc = "paired data 4-by-4",
-  code = {
-    set.seed(123)
-
-    # making data
-    Input <- ("
-    Before        Pastafarian2   Discordiant2   Dudist2   Jedi2
-    Pastafarian   7              0              23         0
-    Discordiant   0              7               0        33
-    Dudist        3              0               7         1
-    Jedi          0              1               0         7
-    ")
-
-    # matrix
-    matrix_df <- as.matrix(read.table(textConnection(Input),
-      header = TRUE,
-      row.names = 1
-    ))
-
-    # cleaning the factor levels
-    df <-
-      as.data.frame(as.table(matrix_df)) %>%
-      dplyr::mutate(Var2 = dplyr::case_when(
-        Var2 == "Pastafarian2" ~ "Pastafarian",
-        Var2 == "Discordiant2" ~ "Discordiant",
-        Var2 == "Dudist2" ~ "Dudist",
-        Var2 == "Jedi2" ~ "Jedi"
-      ))
-
-    # `statsExpressions` output
-    set.seed(123)
-    subtitle1 <-
-      suppressWarnings(contingency_table(
-        data = df,
-        x = Var1,
-        y = Var2,
-        counts = "Freq",
-        paired = TRUE,
-        k = 4,
-        conf.level = 0.99,
-        nboot = 50
-      ))
-
-    # expected output
-    set.seed(123)
-    results1 <-
-      ggplot2::expr(
-        paste(
-          chi["McNemar"]^2,
-          "(",
-          "6",
-          ") = ",
-          "NaN",
-          ", ",
-          italic("p"),
-          " = ",
-          "NaN",
-          ", ",
-          widehat(italic("g"))["Cohen"],
-          " = ",
-          "0.2955",
-          ", CI"["99%"],
-          " [",
-          "0.1659",
-          ", ",
-          "0.3835",
-          "]",
-          ", ",
-          italic("n")["pairs"],
-          " = ",
-          "89"
-        )
-      )
-
-    # testing overall call
-    expect_identical(subtitle1$expression[[1]], results1)
-
-    # edge case
-    dfEx <-
-      data.frame(
-        cat1 = rep(c("A", "B"), 10),
-        cat2 = c(rep("C", 10), rep("D", 10))
-      )
-
-    # subtitle
-    set.seed(123)
-    subtitle2 <-
-      contingency_table(
-        data = dfEx,
-        x = cat1,
-        y = cat2,
-        paired = TRUE
-      )
-
-    results2 <-
-      ggplot2::expr(
-        paste(
-          chi["McNemar"]^2,
-          "(",
-          "1",
-          ") = ",
-          "0.00",
-          ", ",
-          italic("p"),
-          " = ",
-          "1.000",
-          ", ",
-          widehat(italic("g"))["Cohen"],
-          " = ",
-          "0.00",
-          ", CI"["95%"],
-          " [",
-          "-0.26",
-          ", ",
-          "0.26",
-          "]",
-          ", ",
-          italic("n")["pairs"],
-          " = ",
-          "20"
-        )
-      )
-
-    # testing overall call
-    expect_identical(subtitle2$expression[[1]], results2)
-  }
-)
-
 # one-sample test (without counts) -----------------------------------------
 
 test_that(
@@ -753,169 +620,166 @@ test_that(
 )
 
 
-if (packageVersion("parameters") > "0.11.0") {
+# bayes factor (proportion test) --------------------------------------
 
-  # bayes factor (proportion test) --------------------------------------
+test_that(
+  desc = "bayes factor (proportion test)",
+  code = {
 
-  test_that(
-    desc = "bayes factor (proportion test)",
-    code = {
-
-      # extracting results from where this function is implemented
-      set.seed(123)
-      df <-
-        contingency_table(
-          type = "bayes",
-          data = mtcars,
-          x = am
-        )
-
-      # check bayes factor values
-      expect_equal(df$bf10, 0.2465787, tolerance = 0.001)
-
-      # expr
-      set.seed(123)
-      expr_text <-
-        contingency_table(
-          type = "bayes",
-          data = mtcars,
-          x = "cyl",
-          prior.concentration = 10,
-          top.text = "duh"
-        )
-
-      expect_identical(
-        expr_text$expression[[1]],
-        ggplot2::expr(
-          atop(displaystyle("duh"),
-            expr =
-              paste(
-                "log"["e"] * "(BF"["01"] * ") = " * "0.55" * ", ",
-                italic("a")["Gunel-Dickey"] * " = " * "10.00"
-              )
-          )
-        )
-      )
-    }
-  )
-
-  # bayes factor (contingency tab) --------------------------------------
-
-  test_that(
-    desc = "bayes factor (contingency tab)",
-    code = {
-
-
-      # extracting results from where this function is implemented
-      set.seed(123)
-      df_results <-
-        contingency_table(
-          type = "bayes",
-          data = mtcars,
-          x = "am",
-          y = cyl,
-          sampling.plan = "jointMulti",
-          fixed.margin = "rows"
-        )
-
-      # objects
-      expect_identical(class(df_results), c("tbl_df", "tbl", "data.frame"))
-
-      # check bayes factor values
-      expect_equal(df_results$bf10[[1]], 28.07349, tolerance = 0.001)
-
-      # expr
-      set.seed(123)
-      expr_text1 <-
-        contingency_table(
-          type = "bayes",
-          data = mtcars,
-          x = colnames(mtcars)[9],
-          y = "cyl",
-          sampling.plan = "jointMulti",
-          fixed.margin = "rows",
-          conf.level = 0.89,
-          k = 3L
-        )
-
-      # with counts
-      set.seed(123)
-      expr_text2 <-
-        contingency_table(
-          type = "bayes",
-          data = as.data.frame(Titanic),
-          x = "Survived",
-          y = colnames(as.data.frame(Titanic))[2],
-          counts = "Freq",
-          sampling.plan = "jointMulti",
-          fixed.margin = "rows",
-          conf.level = 0.99,
-          k = 3L
-        )
-
-      # with counts
-      set.seed(123)
-      expr_text3 <-
-        contingency_table(
-          type = "bayes",
-          data = as.data.frame(Titanic),
-          x = Survived,
-          y = Sex,
-          counts = "Freq",
-          k = 3L,
-          prior.concentration = 1.5
-        )
-
-      # expr text
-      expect_identical(
-        expr_text1$expression[[1]],
-        ggplot2::expr(
-          paste(
-            "log"["e"] * "(BF"["01"] * ") = " * "-3.335" * ", ",
-            widehat(italic("V"))["Cramer"]^"posterior" * " = " * "0.479" * ", ",
-            "CI"["89%"]^"HDI" * " [" * "0.285" * ", " * "0.692" * "], ",
-            italic("a")["Gunel-Dickey"] * " = " * "1.000"
-          )
-        )
+    # extracting results from where this function is implemented
+    set.seed(123)
+    df <-
+      contingency_table(
+        type = "bayes",
+        data = mtcars,
+        x = am
       )
 
-      expect_type(expr_text2$expression[[1]], "language")
-      expect_type(expr_text3$expression[[1]], "language")
+    # check bayes factor values
+    expect_equal(df$bf10, 0.2465787, tolerance = 0.001)
 
-      expect_identical(
-        expr_text2$expression[[1]],
-        ggplot2::expr(
-          paste(
-            "log"["e"] * "(BF"["01"] * ") = " * "-214.255" * ", ",
-            widehat(italic("V"))["Cramer"]^"posterior" * " = " * "0.455" * ", ",
-            "CI"["99%"]^"HDI" * " [" * "0.402" * ", " * "0.508" * "], ",
-            italic("a")["Gunel-Dickey"] * " = " * "1.000"
-          )
-        )
+    # expr
+    set.seed(123)
+    expr_text <-
+      contingency_table(
+        type = "bayes",
+        data = mtcars,
+        x = "cyl",
+        prior.concentration = 10,
+        top.text = "duh"
       )
 
-      expect_identical(
-        expr_text3$expression[[1]],
-        ggplot2::expr(
-          paste(
-            "log"["e"] * "(BF"["01"] * ") = " * "-213.873" * ", ",
-            widehat(italic("V"))["Cramer"]^"posterior" * " = " * "0.454" * ", ",
-            "CI"["95%"]^"HDI" * " [" * "0.417" * ", " * "0.495" * "], ",
-            italic("a")["Gunel-Dickey"] * " = " * "1.500"
-          )
+    expect_identical(
+      expr_text$expression[[1]],
+      ggplot2::expr(
+        atop(displaystyle("duh"),
+          expr =
+            paste(
+              "log"["e"] * "(BF"["01"] * ") = " * "0.55" * ", ",
+              italic("a")["Gunel-Dickey"] * " = " * "10.00"
+            )
         )
       )
-    }
-  )
+    )
+  }
+)
 
-  # check edge cases - bayes --------------------------------------------
+# bayes factor (contingency tab) --------------------------------------
 
-  test_that(
-    desc = "check edge cases - bayes",
-    code = {
-      df <- data.frame(x = c("a"))
+test_that(
+  desc = "bayes factor (contingency tab)",
+  code = {
 
-      expect_null(contingency_table(type = "bayes", df, x))
-    }
-  )
-}
+
+    # extracting results from where this function is implemented
+    set.seed(123)
+    df_results <-
+      contingency_table(
+        type = "bayes",
+        data = mtcars,
+        x = "am",
+        y = cyl,
+        sampling.plan = "jointMulti",
+        fixed.margin = "rows"
+      )
+
+    # objects
+    expect_identical(class(df_results), c("tbl_df", "tbl", "data.frame"))
+
+    # check bayes factor values
+    expect_equal(df_results$bf10[[1]], 28.07349, tolerance = 0.001)
+
+    # expr
+    set.seed(123)
+    expr_text1 <-
+      contingency_table(
+        type = "bayes",
+        data = mtcars,
+        x = colnames(mtcars)[9],
+        y = "cyl",
+        sampling.plan = "jointMulti",
+        fixed.margin = "rows",
+        conf.level = 0.89,
+        k = 3L
+      )
+
+    # with counts
+    set.seed(123)
+    expr_text2 <-
+      contingency_table(
+        type = "bayes",
+        data = as.data.frame(Titanic),
+        x = "Survived",
+        y = colnames(as.data.frame(Titanic))[2],
+        counts = "Freq",
+        sampling.plan = "jointMulti",
+        fixed.margin = "rows",
+        conf.level = 0.99,
+        k = 3L
+      )
+
+    # with counts
+    set.seed(123)
+    expr_text3 <-
+      contingency_table(
+        type = "bayes",
+        data = as.data.frame(Titanic),
+        x = Survived,
+        y = Sex,
+        counts = "Freq",
+        k = 3L,
+        prior.concentration = 1.5
+      )
+
+    # expr text
+    expect_identical(
+      expr_text1$expression[[1]],
+      ggplot2::expr(
+        paste(
+          "log"["e"] * "(BF"["01"] * ") = " * "-3.335" * ", ",
+          widehat(italic("V"))["Cramer"]^"posterior" * " = " * "0.479" * ", ",
+          "CI"["89%"]^"HDI" * " [" * "0.285" * ", " * "0.692" * "], ",
+          italic("a")["Gunel-Dickey"] * " = " * "1.000"
+        )
+      )
+    )
+
+    expect_type(expr_text2$expression[[1]], "language")
+    expect_type(expr_text3$expression[[1]], "language")
+
+    expect_identical(
+      expr_text2$expression[[1]],
+      ggplot2::expr(
+        paste(
+          "log"["e"] * "(BF"["01"] * ") = " * "-214.255" * ", ",
+          widehat(italic("V"))["Cramer"]^"posterior" * " = " * "0.455" * ", ",
+          "CI"["99%"]^"HDI" * " [" * "0.402" * ", " * "0.508" * "], ",
+          italic("a")["Gunel-Dickey"] * " = " * "1.000"
+        )
+      )
+    )
+
+    expect_identical(
+      expr_text3$expression[[1]],
+      ggplot2::expr(
+        paste(
+          "log"["e"] * "(BF"["01"] * ") = " * "-213.873" * ", ",
+          widehat(italic("V"))["Cramer"]^"posterior" * " = " * "0.454" * ", ",
+          "CI"["95%"]^"HDI" * " [" * "0.417" * ", " * "0.495" * "], ",
+          italic("a")["Gunel-Dickey"] * " = " * "1.500"
+        )
+      )
+    )
+  }
+)
+
+# check edge cases - bayes --------------------------------------------
+
+test_that(
+  desc = "check edge cases - bayes",
+  code = {
+    df <- data.frame(x = c("a"))
+
+    expect_null(contingency_table(type = "bayes", df, x))
+  }
+)
